import {useEffect, useState} from "react";
import {Plant} from "../utils/schemas";
import useGrowbrosFetcher from "../utils/useGrowbrosFetcher";
import {IBackendConnector} from "../utils/IBackendConnector";
import PlantsOverview from "../components/PlantsOverview";
import DropDownFilter from "../components/DropDownFilter";

function Wunschliste() {
    const [plants, setPlantsInWishlist] = useState<Plant[]>([]);
    console.log(plants);
    const [error, setError] = useState({});
    const [currentSort, setCurrentSort] = useState<string>("")

    const bc: IBackendConnector = useGrowbrosFetcher();

    useEffect(() => {
        (async () => {
            const result = await bc.getWishlistEntries(currentSort);
            if (result.err) {
                setError(result.err);
            } else {
                setPlantsInWishlist(result.value!);
            }
        })();
    }, [currentSort]);

    const handleClearWishList = async () => {
        if (confirm("Möchtest du wirklich alle Pflanzen aus deiner Wunschliste entfernen?" + "\n" +
            "Diese Aktion kann nicht rückgängig gemacht werden.")) {
                const result = await bc.clearWishlist();
                if (result.err) {
                    setError(result.err);
                } else {
                    setPlantsInWishlist([]);
                }
            }
    }

    const handleSortOptions = async (selectedOption: string) => {
        switch (selectedOption) {
            case "neueste zuerst":
                setCurrentSort("createdAt");
                break;
            case "als nächstes anpflanzbar":
                setCurrentSort("plantDate");
                break;
            case "gerade anpflanzbar":
                setCurrentSort("currentPlantable");
                break;
            default:
                setCurrentSort("");
        }
    };

    return (
        <>
            <div style={{padding: "20px"}}>
                <h2>Deine Wunschliste</h2>
                <DropDownFilter
                    filterOnChange={handleSortOptions}
                    topic={"Sortierung der Pflanzen in der Wunschliste"}
                    options={[
                        "neueste zuerst",
                        "als nächstes anpflanzbar",
                        "gerade anpflanzbar",
                    ]}
                />
                <button onClick={handleClearWishList}>Wunschliste leeren</button>
            </div>
            <PlantsOverview plants={plants}/>
        </>
    );
}
export default Wunschliste;